@@ -1,11 +1,11 @@
-/* electric_field.h -- This file is part of Archimedes release 0.0.1.
-   Archimedes is a simulator for Submicron 2D Silicon
+/* electric_field.h -- This file is part of Archimedes release 0.0.2.
+   Archimedes is a simulator for Submicron 2D Silicon/GaAs
    Devices. It implements the Monte Carlo method
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
    of effective potential method.
 
-   Copyright (C) 2004 Jean Michel Sellier <sellier@dmi.unict.it>
+   Copyright (C) 2004, 2005 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ Electric_Field(void)
  PoissonBCs();
 // ===============================
  factor=0.9;
- kappa=(EPS0*EPSR)/Q;
+ kappa=(epsMATERIAL)/Q;
  deltat=factor*0.5/kappa/(1./(dx*dx)+1./(dy*dy));
 // calcolo del potenziale "stazionario"
  for(i=1;i<=POISSONITMAX;i++){
